==> compiler-2.3.3-sources.jar: android/databinding/tool/reflection/InjectedField.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.databinding.tool.reflection;

import android.databinding.Bindable;

import java.util.Map;

/**
 * A class that can be used by ModelAnalyzer without any backing model. This is used
 * for fields on ViewDataBinding subclasses that haven't been generated yet.
 *
 * @see ModelAnalyzer#injectViewDataBinding(String, Map, Map)
 */
public class InjectedField extends ModelField {
    private final String mType;
    private final String mName;

    public InjectedField(String name, String type) {
        mName = name;
        mType = type;
    }

    @Override
    public boolean isBindable() {
        return false;
    }

    @Override
    public String getName() {
        return mName;
    }

    @Override
    public boolean isPublic() {
        return true;
    }

    @Override
    public boolean isStatic() {
        return false;
    }

    @Override
    public boolean isFinal() {
        return true;
    }

    @Override
    public ModelClass getFieldType() {
        return ModelAnalyzer.getInstance().findClass(mType, null);
    }
}

==> compiler-3.1.0-sources.jar: android/databinding/tool/reflection/InjectedField.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.databinding.tool.reflection;

import java.util.Map;

/**
 * A class that can be used by ModelAnalyzer without any backing model. This is used
 * for fields on ViewDataBinding subclasses that haven't been generated yet.
 *
 * @see ModelAnalyzer#injectViewDataBinding(String, Map, Map, java.util.HashMap)
 */
public class InjectedField extends ModelField {
    private final String mType;
    private final String mName;

    public InjectedField(String name, String type) {
        mName = name;
        mType = type;
    }

    @Override
    public boolean isBindable() {
        return false;
    }

    @Override
    public String getName() {
        return mName;
    }

    @Override
    public boolean isPublic() {
        return true;
    }

    @Override
    public boolean isStatic() {
        return false;
    }

    @Override
    public boolean isFinal() {
        return true;
    }

    @Override
    public ModelClass getFieldType() {
        return ModelAnalyzer.getInstance().findClass(mType, null);
    }
}
